## ----message=FALSE-------------------------------------------------------
library(Biostrings)
library(metagenomeFeatures)
library(metagenomeSeq)
library(magrittr)

## ------------------------------------------------------------------------
dataDirectory <- system.file("extdata", package = "metagenomeFeatures")

assay_data <- file.path(dataDirectory, "msd16s_counts.csv") %>% load_meta(sep = ",")

pheno_data <- file.path(dataDirectory, "msd16s_sample_data.csv") %>% 
    read.csv(row.names = 1, stringsAsFactors = F) %>% AnnotatedDataFrame()

## ------------------------------------------------------------------------
demoMRexp = newMRexperiment(assay_data$counts, phenoData=pheno_data)
demoMRexp

## ----echo=FALSE, message=FALSE-------------------------------------------
metadata <- list(ACCESSION_DATE = "3/31/2015",
                 URL = "https://greengenes.microbio.me",
                 DB_TYPE_NAME = "GreenGenes-MgDb-msd16s",
                 DB_TYPE_VALUE = "MgDb",
                 DB_SCHEMA_VERSION = "1.0")

db_seq <- file.path(dataDirectory,"msd16s_MgDb_seq.fasta.gz") %>% 
    readDNAStringSet()

msd16s_MgDb <- new("MgDb",
                seq = db_seq,
                taxa_file = file.path(dataDirectory,"msd16s_MgDb_taxa.sqlite"),
                tree_file = file.path(dataDirectory,"msd16s_MgDb_tree.rds"),
                metadata = metadata)

## ------------------------------------------------------------------------
demoMRexp <- annotateMRexp_fData(mgdb = msd16s_MgDb, MRobj = demoMRexp)
demoMRexp

## ------------------------------------------------------------------------
sessionInfo()

